@@ -1,5 +1,5 @@
 #!/bin/bash
-# Push to pypi, tag and push to bitbucket
+# Push to pypi
 
 ver=$(python setup.py --version)
 
@@ -16,28 +16,36 @@ else
 fi
 
 OSes="win_amd64
-win32
-macosx_10_13_x86_64
-manylinux1_x86_64"
+macosx_10_14_x86_64
+manylinux2014_x86_64
+manylinux2014_aarch64"
 
-PyVers="27
-35
-36
+PyVers="36
 37"
 
 for os in $OSes; do
     for pyver in $PyVers; do
+        if [[ ${os} == "manylinux2014_aarch64" && ${pyver} == "37" ]]; then
+            continue # Currently having trouble building ARM64 for Python 3.7
+        fi
         wget -q --directory-prefix=dist/ https://github.com/fastavro/fastavro/releases/download/${ver}/fastavro-${ver}-cp${pyver}-cp${pyver}m-${os}.whl
     done
 done
 
-# Get the 38 versions
-for os in $OSes; do
-    wget -q --directory-prefix=dist/ https://github.com/fastavro/fastavro/releases/download/${ver}/fastavro-${ver}-cp38-cp38-${os}.whl
-done
+PyVers="38
+39"
 
-# Also get the linux 2.7mu version
-wget -q --directory-prefix=dist/ https://github.com/fastavro/fastavro/releases/download/${ver}/fastavro-${ver}-cp27-cp27mu-manylinux1_x86_64.whl
+for os in $OSes; do
+    for pyver in $PyVers; do
+        if [[ ${os} == "manylinux2014_aarch64" && ${pyver} == "39" ]]; then
+            continue # Currently having trouble building ARM64 for Python 3.9
+        fi
+        if [[ ${os} == "manylinux2014_aarch64" && ${pyver} == "38" ]]; then
+            continue # Currently having trouble building ARM64 for Python 3.9
+        fi
+        wget -q --directory-prefix=dist/ https://github.com/fastavro/fastavro/releases/download/${ver}/fastavro-${ver}-cp${pyver}-cp${pyver}-${os}.whl
+    done
+done
 
 make fresh
 FASTAVRO_USE_CYTHON=1 python setup.py sdist
